Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(59)

Unified Diff: app/menus/button_menu_item_model.h

Issue 5697005: Change SimpleMenuModel on OSX to support dynamic icons (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Update after merge Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | app/menus/button_menu_item_model.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: app/menus/button_menu_item_model.h
diff --git a/app/menus/button_menu_item_model.h b/app/menus/button_menu_item_model.h
index 265359be1a93af6c049e659d643175676d5f3b70..4b4c98c8eddef3dd9c5c128992f12aa707d516c4 100644
--- a/app/menus/button_menu_item_model.h
+++ b/app/menus/button_menu_item_model.h
@@ -26,7 +26,7 @@ class ButtonMenuItemModel {
class Delegate {
public:
// Some command ids have labels that change over time.
- virtual bool IsLabelForCommandIdDynamic(int command_id) const;
+ virtual bool IsItemForCommandIdDynamic(int command_id) const;
virtual string16 GetLabelForCommandId(int command_id) const;
// Performs the action associated with the specified command id.
@@ -49,7 +49,7 @@ class ButtonMenuItemModel {
void AddItemWithImage(int command_id, int icon_idr);
// Adds a non-clickable button with a desensitized label that doesn't do
// anything. Usually combined with IsLabelForCommandIdDynamic() to add
// information.
void AddButtonLabel(int command_id, int string_id);
@@ -66,7 +66,7 @@ class ButtonMenuItemModel {
int GetCommandIdAt(int index) const;
// Whether the label for item |index| changes.
- bool IsLabelDynamicAt(int index) const;
+ bool IsItemDynamicAt(int index) const;
// Returns the current label value for the button at |index|.
string16 GetLabelAt(int index) const;
« no previous file with comments | « no previous file | app/menus/button_menu_item_model.cc » ('j') | no next file with comments »
@@ -49,7 +49,7 @@ class ButtonMenuItemModel {
void AddItemWithImage(int command_id, int icon_idr);
// Adds a non-clickable button with a desensitized label that doesn't do
- // anything. Usually combined with IsLabelForCommandIdDynamic() to add
+ // anything. Usually combined with IsItemForCommandIdDynamic() to add
// information.
void AddButtonLabel(int command_id, int string_id);

Powered by Google App Engine
This is Rietveld 408576698